@@ -1,7 +1,7 @@
 package HTML::TreeBuilder::LibXML;
 use strict;
 use warnings;
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 use Carp ();
 use base 'HTML::TreeBuilder::LibXML::Node';
 use XML::LibXML;
@@ -48,6 +48,12 @@ sub parse {
     $self->{_content} .= $html;
 }
 
+sub parse_content {
+    my $self = shift;
+    $self->parse($_[0]);
+    $self->eof;
+}
+
 sub parse_file {
     my $self = shift;
     my $doc  = $self->_parser->parse_html_file(@_);
@@ -70,6 +76,10 @@ sub _documentElement {
     };
 }
 
+sub elementify {
+    bless shift, 'HTML::TreeBuilder::LibXML::Node';
+}
+
 sub replace_original {
     require HTML::TreeBuilder::XPath;
 
